@@ -33,7 +33,7 @@ does not provide a name, a default one will be created and assigned by Kodra.
 
 
 def share(
-    data: pandas.DataFrame, token: str, name: Optional[str] = "My Dataset"
+    data: pandas.DataFrame, name: Optional[str] = "My Dataset"
 ) -> Tuple[int, str]:
     """Top level method to upload a DataFrame to Kodra with default Client.
 
@@ -112,22 +112,6 @@ class Client:
             time.sleep(10)
         return False
 
-    def attempt_to_open_browser(self, url: str) -> None:
-        """Attempts to open the provided URL in the user's browser, assuming a
-        a notebook environment.
-        """
-        try:
-            import IPython
-            from IPython.display import Javascript, display
-
-            display(Javascript("window.open('{}')".format(url)))
-        except Exception as e:
-            print("Unable to open browser automatically.")
-        print(
-            "If it doesn't open automatically, please visit the following URL to authorize this upload:"
-        )
-        print("\t" + url)
-
     def share(
         self, data: pandas.DataFrame, name: Optional[str] = "My Dataset"
     ) -> Tuple[int, str]:
@@ -169,7 +153,8 @@ class Client:
         token_auth_ui_url = self.kodra_notebook_token_auth_ui.format(
             token
         ) + "?dataset_name={}".format(urllib.parse.quote(name, safe=""))
-        self.attempt_to_open_browser(token_auth_ui_url)
+        print("Please visit the following URL to authorize this upload:")
+        print("\t" + token_auth_ui_url)
 
         # Wait for the token to be authorized
         print("Waiting for upload to be authorized...")
